@@ -36,13 +36,15 @@ namespace xpyt
         xstream(std::string stream_name);
         virtual ~xstream();
 
-        void write(const std::string& message);
+        py::object get_write();
+        void set_write(const py::object& func);
         void flush();
         bool isatty();
 
     private:
 
         std::string m_stream_name;
+        py::object m_write_func;
     };
 
     /**************************
@@ -50,7 +52,9 @@ namespace xpyt
      **************************/
 
     xstream::xstream(std::string stream_name)
-        : m_stream_name(stream_name)
+        : m_stream_name(stream_name), m_write_func(py::cpp_function([stream_name](const std::string& message) {
+            xeus::get_interpreter().publish_stream(stream_name, message);
+        }))
     {
     }
 
@@ -58,9 +62,14 @@ namespace xpyt
     {
     }
 
-    void xstream::write(const std::string& message)
+    py::object xstream::get_write()
     {
-        xeus::get_interpreter().publish_stream(m_stream_name, message);
+        return m_write_func;
+    }
+
+    void xstream::set_write(const py::object& func)
+    {
+        m_write_func = func;
     }
 
     void xstream::flush()
@@ -83,8 +92,13 @@ namespace xpyt
         xterminal_stream();
         virtual ~xterminal_stream();
 
-        void write(const std::string& message);
+        py::object get_write();
+        void set_write(const py::object& func);
         void flush();
+
+    private:
+
+        py::object m_write_func;
     };
 
     /***********************************
@@ -92,6 +106,9 @@ namespace xpyt
      ***********************************/
 
     xterminal_stream::xterminal_stream()
+        : m_write_func(py::cpp_function([](const std::string& message) {
+            std::cout << message;
+        }))
     {
     }
 
@@ -99,9 +116,14 @@ namespace xpyt
     {
     }
 
-    void xterminal_stream::write(const std::string& message)
+    py::object xterminal_stream::get_write()
     {
-        std::cout << message;
+        return m_write_func;
+    }
+
+    void xterminal_stream::set_write(const py::object& func)
+    {
+        m_write_func = func;
     }
 
     void xterminal_stream::flush()
@@ -118,13 +140,13 @@ namespace xpyt
 
         py::class_<xstream>(stream_module, "Stream")
             .def(py::init<std::string>())
-            .def("write", &xstream::write)
+            .def_property("write", &xstream::get_write, &xstream::set_write)
             .def("flush", &xstream::flush)
             .def("isatty", &xstream::isatty);
 
         py::class_<xterminal_stream>(stream_module, "TerminalStream")
             .def(py::init<>())
-            .def("write", &xterminal_stream::write)
+            .def_property("write", &xterminal_stream::get_write, &xterminal_stream::set_write)
             .def("flush", &xterminal_stream::flush);
 
         return stream_module;
