@@ -8,9 +8,9 @@
 * The full license is in the file LICENSE, distributed with this software. *
 ****************************************************************************/
 
+#include <algorithm>
 #include <map>
 #include <vector>
-#include <sstream>
 #include <string>
 
 #include "xeus-python/xutils.hpp"
@@ -24,40 +24,9 @@ namespace py = pybind11;
 
 namespace xpyt
 {
-    std::string highlight(const std::string& code)
+    py::str get_filename(const py::str& raw_code)
     {
-        py::object py_highlight = py::module::import("pygments").attr("highlight");
-        // py::module::import("pygments").attr("formatters") does NOT work due
-        // to side effects when importing pygments
-        py::object formatter = py::module::import("pygments.formatters").attr("TerminalFormatter");
-
-        py::object lexer = py::module::import("pygments.lexers").attr("Python3Lexer");
-
-        return py::str(py_highlight(code, lexer(), formatter()));
-    }
-
-    std::string extract_line(const std::string& code, std::size_t lineno)
-    {
-        std::istringstream code_stream(code);
-        std::string line;
-
-        for (std::size_t line_number(0); line_number < lineno; line_number++)
-        {
-            std::getline(code_stream, line);
-        }
-
-        // Remove indentation
-        if (!line.empty())
-        {
-            std::size_t idx(0);
-            while (line[idx] == ' ')
-            {
-                idx++;
-            }
-            line = line.substr(idx);
-        }
-
-        return line;
+        return get_cell_tmp_file(raw_code);
     }
 
     using filename_map = std::map<std::string, int>;
@@ -73,20 +42,46 @@ namespace xpyt
         get_filename_map()[filename] = execution_count;
     }
 
-    xerror extract_error(const py::object& type, const py::object& value, const py::object& traceback)
+    xerror extract_error(const py::list& error)
     {
         xerror out;
 
+        out.m_ename = error[0].cast<std::string>();
+        out.m_evalue = error[1].cast<std::string>();
+
+        py::list tb = error[2];
+
+        std::transform(
+            tb.begin(), tb.end(), std::back_inserter(out.m_traceback),
+            [](py::handle obj) -> std::string { return obj.cast<std::string>(); }
+        );
+
+        return out;
+    }
+
+    xerror extract_already_set_error(py::error_already_set& error)
+    {
+        xerror out;
+
+        // Fetch the error message, it must be released by the C++ exception first
+        error.restore();
+
+        py::object py_type;
+        py::object py_value;
+        py::object py_tb;
+        PyErr_Fetch(&py_type.ptr(), &py_value.ptr(), &py_tb.ptr());
+
         // This should NOT happen
-        if (type.is_none())
+        if (py_type.is_none())
         {
             out.m_ename = "Error";
-            out.m_evalue = "";
+            out.m_evalue = error.what();
+            out.m_traceback.push_back(error.what());
         }
         else
         {
-            out.m_ename = py::str(type.attr("__name__"));
-            out.m_evalue = py::str(value);
+            out.m_ename = py::str(py_type.attr("__name__"));
+            out.m_evalue = py::str(py_value);
 
             std::size_t first_frame_size(75);
             std::string delimiter(first_frame_size, '-');
@@ -98,9 +93,9 @@ namespace xpyt
                         << red_text(out.m_ename) << first_frame_padding << traceback_msg;
             out.m_traceback.push_back(first_frame.str());
 
-            if (traceback.ptr() != nullptr && !traceback.is_none())
+            if (py_tb.ptr() != nullptr && !py_tb.is_none())
             {
-                for (py::handle py_frame : py::module::import("traceback").attr("extract_tb")(traceback))
+                for (py::handle py_frame : py::module::import("traceback").attr("extract_tb")(py_tb))
                 {
                     std::string filename;
                     std::string lineno;
@@ -156,11 +151,6 @@ namespace xpyt
         return out;
     }
 
-    xerror extract_error(py::error_already_set& error)
-    {
-        return extract_error(error.type(), error.value(), error.trace());
-    }
-
     /********************
      * traceback module *
      ********************/
@@ -169,34 +159,17 @@ namespace xpyt
     {
         py::module traceback_module = create_module("traceback");
 
+        traceback_module.def("get_filename",
+            get_filename,
+            py::arg("raw_code")
+        );
+
         traceback_module.def("register_filename_mapping",
             register_filename_mapping,
             py::arg("filename"),
             py::arg("execution_count")
         );
 
-        exec(py::str(R"(
-last_error = None
-
-
-def reset_last_error():
-    global last_error
-
-    last_error = None
-
-
-def set_last_error(type, value, traceback):
-    global last_error
-
-    last_error = (type, value, traceback)
-
-
-def get_last_error():
-    global last_error
-
-    return last_error
-        )"), traceback_module.attr("__dict__"));
-
         return traceback_module;
     }
 
